@@ -6,14 +6,13 @@
 A python package with reusable functions and utility classes. 
 """
 __author__="Ohidur Rahman Bappy"
-__version__="0.0.1"
+__version__="0.0.4"
 __license__ = "MIT"
 __status__ = "Production"
 
 __all__=[
-    'AppConfig','Config','NameSpace'
+    'AppConfig','Config','Namespace'
 ]
 
 from .config import AppConfig,Config
 from .namespace import Namespace
-
